"""Commandline interface for the library."""
import textwrap
from random import randint
from typing import List

import click
from arkhamdb import __version__
from arkhamdb.utils import async_command
from httpx import AsyncClient, Response

API_URL = "https://arkhamdb.com/api"


@click.command()
@click.version_option(version=__version__)
@async_command
async def main():
    """Commandline interface for a utility tool that provides a pythonic interface for the excellent ArkhamDB.com."""  # noqa: E501
    click.echo("Obtaining latest cards list from ArkhamDB.com ...")

    async with AsyncClient(
        base_url=API_URL,
        headers={"Content-Type": "application/json"},
        follow_redirects=True,
    ) as client:
        try:
            res: Response = await client.get("public/cards")
            cards: List[dict] = res.json()
            click.secho(f"Remote database contains {len(cards)} cards.", fg="green")
            click.echo(textwrap.fill("========================================"))
            i = randint(0, len(cards) - 1)  # nosec # noqa
            example = cards[i]
            click.echo(f"{example['name']} | {example['faction_name']}")
            click.echo(textwrap.fill("========================================"))
            click.echo(f"Description: {textwrap.fill(example['text'])}")
        except Exception as e:
            msg = str(e)
            raise click.ClickException(msg) from e



"""Pythonic wrapper around the excellent `ArkhamDB API <https://arkhamdb.com/api/>`__. Designed to be standalone and importable to other projects."""  # noqa: E501

# uses the version from pyproject.toml via importlib.metadata
# for python versions < 3.7 need to add the backport
# poetry add --python="<3.8" importlib_metadata
try:
    from importlib.metadata import PackageNotFoundError, version  # type: ignore # noqa
except ImportError:  # pragma: no cover # noqa
    from importlib_metadata import PackageNotFoundError, version  # type: ignore # noqa
try:  # noqa
    __version__ = version(__name__)
except PackageNotFoundError:  # pragma: no cover
    __version__ = "unknown"



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['arkhamdb']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.3,<9.0.0', 'httpx>=0.22.0,<0.23.0']

extras_require = \
{':python_version < "3.8"': ['importlib-metadata>=4.11.3,<5.0.0']}

entry_points = \
{'console_scripts': ['arkhamdb = arkhamdb.console:main']}

setup_kwargs = {
    'name': 'arkhamdb',
    'version': '0.0.6',
    'description': 'Pythonic wrapper around the excellent ArkhamDB API. Designed to be standalone and importable to other projects.',
    'long_description': '# python-arkhamdb\n\n![pypi_license](https://img.shields.io/pypi/l/arkhamdb)[![status-badge](https://ci.jamesveitch.xyz/api/badges/james/python-arkhamdb/status.svg)](https://ci.jamesveitch.xyz/james/python-arkhamdb)[![Read the Docs](https://readthedocs.org/projects/arkhamdb/badge/)](https://arkhamdb.readthedocs.io/)\n![pypi_versions](https://img.shields.io/pypi/v/arkhamdb)![pypi_python](https://img.shields.io/pypi/pyversions/arkhamdb)![pypi_downloads](https://img.shields.io/pypi/dm/arkhamdb)\n\n<img src="https://arkhamdb.readthedocs.io/en/latest/_static/logo.svg" width="100" style="float:left;clear:both;margin-right:10px"/> Pythonic wrapper around the excellent [ArkhamDB API](https://arkhamdb.com/api/). Designed to be standalone and importable to other projects.\n\nDocumentation can be found at [arkhamdb.readthedocs.io](https://arkhamdb.readthedocs.io). See the [latest](https://arkhamdb.readthedocs.io/en/latest/) branch for the master (stable) code and [develop](https://arkhamdb.readthedocs.io/en/develop/) for current (unstable) working version of the code.\n\n## Simple usage\n\nTODO: add example\n\n## Python Version\n\nThis library is tested against Python 3.7+\n',
    'author': 'James Veitch',
    'author_email': '1722315+darth-veitcher@users.noreply.github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



"""Utility helper functions that are re-used in multiple locations."""
import asyncio
from functools import wraps


# https://github.com/pallets/click/issues/85#issuecomment-503464628
def async_command(f):
    """Wraps a function and allows it to be called asynchronously with click commands."""  # noqa: D401

    @wraps(f)
    def wrapper(*args, **kwargs):
        return asyncio.run(f(*args, **kwargs))

    return wrapper
